# has_medical_history

None

URI: https://w3id.org/linkml/tests/kitchen_sink/has_medical_history



<!-- no inheritance hierarchy -->


## Properties

 * Range: MedicalEvent

## Identifier and Mapping Information


